pecos.error\_models.old.depolar\_gen
====================================

.. automodule:: pecos.error_models.old.depolar_gen











   .. rubric:: Classes

   .. autosummary::

      DepolarModel
